@@ -12,10 +12,8 @@ import os.path
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib import animation
-from numpy.lib.arraysetops import isin
 from spatialmath import base
-from collections.abc import Iterable, Generator, Iterator
-import time
+from collections.abc import Iterable, Iterator
 
 # global variable holds reference to FuncAnimation object, this is essential
 # for animatiion to work
@@ -251,7 +249,7 @@ class Animate:
             # animation and wait for its callback to be deregistered.
             while True:
                 plt.pause(0.25)
-                if len(_ani.event_source.callbacks) == 0:
+                if _ani.event_source is None or len(_ani.event_source.callbacks) == 0:
                     break
 
     def __repr__(self):
@@ -818,9 +816,8 @@ if __name__ == "__main__":
 
     from spatialmath import base
 
-    T = base.rpy2r(0.3, 0.4, 0.5)
+    # T = base.rpy2r(0.3, 0.4, 0.5)
     # base.tranimate(T, wait=True)
 
     T = base.rot2(2)
     base.tranimate2(T, wait=True)
-    pass
