@@ -3,10 +3,18 @@
 # MIT Licence, see details in top-level file: LICENCE
 
 import numpy as np
-from sympy.core.singleton import S
-from spatialmath.base import base
+
+# try:  # pragma: no cover
+#     # print('Using SymPy')
+#     from sympy.core.singleton import S
+
+#     _symbolics = True
+
+# except ImportError:  # pragma: no cover
+#     _symbolics = False
+
+import spatialmath.base as base
 from spatialmath.baseposelist import BasePoseList
-from spatialmath.base import symbolic as sym
 
 _eps = np.finfo(np.float64).eps
 
@@ -14,6 +22,7 @@ _eps = np.finfo(np.float64).eps
 #   colored package has much finer control than colorama, but the latter is available by default with anaconda
 try:
     from colored import fg, bg, attr
+
     _colored = True
     # print('using colored output')
 except ImportError:
@@ -22,6 +31,7 @@ except ImportError:
 
 try:
     from ansitable import ANSIMatrix
+
     _ANSIMatrix = True
     # print('using colored output')
 except ImportError:
@@ -48,7 +58,7 @@ class BasePoseMatrix(BasePoseList):
     - ``+`` will add two instances of the same subclass, and the result will be
       a matrix, not an instance of the same subclass, since addition is not a group operator.
 
-    These classes all inherit from ``UserList`` which enables them to 
+    These classes all inherit from ``UserList`` which enables them to
     represent a sequence of values, ie. an ``SE3`` instance can contain
     a sequence of SE(3) values.  Most of the Python ``list`` operators
     are applicable::
@@ -98,23 +108,25 @@ class BasePoseMatrix(BasePoseList):
         is installed.  It does not currently support colorization of elements.
     """
 
-    _rotcolor = 'red'
-    _transcolor = 'blue'
+    _rotcolor = "red"
+    _transcolor = "blue"
     _bgcolor = None
-    _constcolor = 'grey_50'
-    _indexcolor = (None, 'yellow_2')
-    _format = '{:< 9.4g}'
+    _constcolor = "grey_50"
+    _indexcolor = (None, "yellow_2")
+    _format = "{:< 9.4g}"
     _suppress_small = True
     _suppress_tol = 100
     _color = _colored
     _ansimatrix = False
     _ansiformatter = None
 
+    __array_ufunc__ = None  # allow pose matrices operators with NumPy values
+
     def __new__(cls, *args, **kwargs):
         """
         Create the subclass instance (superclass method)
 
-        Create a new instance and call the superclass initializer to enable the 
+        Create a new instance and call the superclass initializer to enable the
         ``UserList`` capabilities.
         """
 
@@ -122,7 +134,7 @@ class BasePoseMatrix(BasePoseList):
         super().__init__(pose)  # initialize UserList
         return pose
 
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
 
     @property
     def about(self):
@@ -132,7 +144,7 @@ class BasePoseMatrix(BasePoseList):
         :return: succinct summary
         :rtype: str
 
-        Displays the type and the number of elements in compact form, for 
+        Displays the type and the number of elements in compact form, for
         example::
 
             >>> x = SE3([SE3() for i in range(20)])
@@ -162,12 +174,12 @@ class BasePoseMatrix(BasePoseList):
             >>> SE2().N
             2
         """
-        if type(self).__name__ == 'SO2' or type(self).__name__ == 'SE2':
+        if type(self).__name__ == "SO2" or type(self).__name__ == "SE2":
             return 2
         else:
             return 3
 
-    #----------------------- tests
+    # ----------------------- tests
     @property
     def isSO(self):
         """
@@ -178,7 +190,7 @@ class BasePoseMatrix(BasePoseList):
         :return: ``True`` if object is instance of SO2 or SO3
         :rtype: bool
         """
-        return type(self).__name__ == 'SO2' or type(self).__name__ == 'SO3'
+        return type(self).__name__ == "SO2" or type(self).__name__ == "SO3"
 
     @property
     def isSE(self):
@@ -190,17 +202,14 @@ class BasePoseMatrix(BasePoseList):
         :return: ``True`` if object is instance of SE2 or SE3
         :rtype: bool
         """
-        return type(self).__name__ == 'SE2' or type(self).__name__ == 'SE3'
+        return type(self).__name__ == "SE2" or type(self).__name__ == "SE3"
 
+    # ------------------------------------------------------------------------ #
 
-# ------------------------------------------------------------------------ #
-
-
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
 
     # --------- compatibility methods
 
-
     def isrot(self):
         """
         Test if object belongs to SO(3) group (superclass method)
@@ -220,7 +229,7 @@ class BasePoseMatrix(BasePoseList):
             >>> x.isrot()
             False
         """
-        return type(self).__name__ == 'SO3'
+        return type(self).__name__ == "SO3"
 
     def isrot2(self):
         """
@@ -241,7 +250,7 @@ class BasePoseMatrix(BasePoseList):
             >>> x.isrot()
             False
         """
-        return type(self).__name__ == 'SO2'
+        return type(self).__name__ == "SO2"
 
     def ishom(self):
         """
@@ -262,7 +271,7 @@ class BasePoseMatrix(BasePoseList):
             >>> x.isrot()
             True
         """
-        return type(self).__name__ == 'SE3'
+        return type(self).__name__ == "SE3"
 
     def ishom2(self):
         """
@@ -283,9 +292,9 @@ class BasePoseMatrix(BasePoseList):
             >>> x.isrot()
             True
         """
-        return type(self).__name__ == 'SE2'
+        return type(self).__name__ == "SE2"
 
-     #----------------------- functions
+    # ----------------------- functions
 
     def det(self):
         """
@@ -295,7 +304,7 @@ class BasePoseMatrix(BasePoseList):
         :rtype: float or NumPy array
 
         ``x.det()`` is the determinant of the rotation component of the values
-        of ``x``.  
+        of ``x``.
 
         Example::
 
@@ -308,17 +317,16 @@ class BasePoseMatrix(BasePoseList):
 
         :SymPy: not supported
         """
-        if type(self).__name__ in ('SO3', 'SE3'):
+        if type(self).__name__ in ("SO3", "SE3"):
             if len(self) == 1:
-                return np.linalg.det(self.A[:3,:3])
+                return np.linalg.det(self.A[:3, :3])
             else:
-                return [np.linalg.det(T[:3,:3]) for T in self.data]
-        elif type(self).__name__ in ('SO2', 'SE2'):
+                return [np.linalg.det(T[:3, :3]) for T in self.data]
+        elif type(self).__name__ in ("SO2", "SE2"):
             if len(self) == 1:
-                return np.linalg.det(self.A[:2,:2])
+                return np.linalg.det(self.A[:2, :2])
             else:
-                return [np.linalg.det(T[:2,:2]) for T in self.data]
-
+                return [np.linalg.det(T[:2, :2]) for T in self.data]
 
     def log(self, twist=False):
         """
@@ -395,7 +403,7 @@ class BasePoseMatrix(BasePoseList):
 
             - For SO3 and SE3 rotation is interpolated using quaternion spherical linear interpolation (slerp).
             - Values of ``s`` outside the range [0,1] are silently clipped
-        :seealso: :func:`interp1`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.slerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
+        :seealso: :func:`interp1`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.qslerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
 
         :SymPy: not supported
         """
@@ -406,21 +414,25 @@ class BasePoseMatrix(BasePoseList):
             s = base.getvector(s)
             s = np.clip(s, 0, 1)
 
-        if len(self) > 1: 
-            raise ValueError('start pose must be a singleton')
+        if len(self) > 1:
+            raise ValueError("start pose must be a singleton")
 
         if end is not None:
-            if len(end) > 1: 
-                raise ValueError('end pose must be a singleton')
+            if len(end) > 1:
+                raise ValueError("end pose must be a singleton")
             end = end.A
 
         if self.N == 2:
             # SO(2) or SE(2)
-            return self.__class__([base.trinterp2(start=self.A, end=end, s=_s) for _s in s])
+            return self.__class__(
+                [base.trinterp2(start=self.A, end=end, s=_s) for _s in s]
+            )
 
         elif self.N == 3:
             # SO(3) or SE(3)
-            return self.__class__([base.trinterp(start=self.A, end=end, s=_s) for _s in s])
+            return self.__class__(
+                [base.trinterp(start=self.A, end=end, s=_s) for _s in s]
+            )
 
     def interp1(self, s=None):
         """
@@ -469,31 +481,32 @@ class BasePoseMatrix(BasePoseList):
 
         #. For SO3 and SE3 rotation is interpolated using quaternion spherical linear interpolation (slerp).
 
-        :seealso: :func:`interp`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.slerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
+        :seealso: :func:`interp`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.qslerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
 
         :SymPy: not supported
         """
         s = base.getvector(s)
         s = np.clip(s, 0, 1)
 
-        if start is not None:
-            assert len(start) == 1, 'len(start) must == 1'
-            start = start.A
-
         if self.N == 2:
             # SO(2) or SE(2)
             if len(s) > 1:
-                assert len(self) == 1, 'if len(s) > 1, len(X) must == 1'
+                assert len(self) == 1, "if len(s) > 1, len(X) must == 1"
                 return self.__class__([base.trinterp2(start, self.A, s=_s) for _s in s])
             else:
-                return self.__class__([base.trinterp2(start, x, s=s[0]) for x in self.data])
+                return self.__class__(
+                    [base.trinterp2(start, x, s=s[0]) for x in self.data]
+                )
         elif self.N == 3:
             # SO(3) or SE(3)
             if len(s) > 1:
-                assert len(self) == 1, 'if len(s) > 1, len(X) must == 1'
-                return self.__class__([base.trinterp(start, self.A, s=_s) for _s in s])
+                assert len(self) == 1, "if len(s) > 1, len(X) must == 1"
+                return self.__class__([base.trinterp(None, self.A, s=_s) for _s in s])
             else:
-                return self.__class__([base.trinterp(start, x, s=s[0]) for x in self.data])
+                return self.__class__(
+                    [base.trinterp(None, x, s=s[0]) for x in self.data]
+                )
+
     def norm(self):
         """
         Normalize pose (superclass method)
@@ -501,7 +514,7 @@ class BasePoseMatrix(BasePoseList):
         :return: pose
         :rtype: SO2, SE2, SO3, SE3 instance
 
-        - ``X.norm()`` is an equivalent pose object but the rotational matrix 
+        - ``X.norm()`` is an equivalent pose object but the rotational matrix
           part of all values has been adjusted to ensure it is a proper orthogonal
           matrix rotation.
 
@@ -518,7 +531,7 @@ class BasePoseMatrix(BasePoseList):
         Notes:
 
         #. Only the direction of A vector (the z-axis) is unchanged.
-        #. Used to prevent finite word length arithmetic causing transforms to 
+        #. Used to prevent finite word length arithmetic causing transforms to
            become 'unnormalized'.
 
         :seealso: :func:`~spatialmath.base.transforms3d.trnorm`, :func:`~spatialmath.base.transforms2d.trnorm2`
@@ -536,7 +549,7 @@ class BasePoseMatrix(BasePoseList):
         :rtype: pose instance
 
         Apply symbolic simplification to every element of every value in the
-        pose instane. 
+        pose instane.
 
         Example::
 
@@ -558,7 +571,7 @@ class BasePoseMatrix(BasePoseList):
         :SymPy: supported
         """
 
-        vf = np.vectorize(sym.simplify)
+        vf = np.vectorize(base.sym.simplify)
         return self.__class__([vf(x) for x in self.data], check=False)
 
     def stack(self):
@@ -576,10 +589,37 @@ class BasePoseMatrix(BasePoseList):
 
     # ----------------------- i/o stuff
 
-    def printline(self, **kwargs):
+    def print(self, label=None, file=None):
         """
-        Print pose in compact single line format (superclass method)
+        Print pose as a matrix (superclass method)
 
+        :param label: label to print before the matrix, defaults to None
+        :type label: str, optional
+        :param file: file to write to, defaults to None
+        :type file: file object, optional
+
+        Print the pose as a matrix, with an optional line beforehand.  By default
+        the matrix is printed to stdout.
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3
+            >>> SE3().print()
+            >>> SE3().print("pose is:")
+
+        """
+        if label is not None:
+            print(label, file=file)
+        print(self, file=file)
+
+    def printline(self, *args, **kwargs):
+        r"""
+        Print pose in compact single line format (superclass method)
+        
+        :param arg: value for orient option, optional
+        :type arg: str
         :param label: text label to put at start of line
         :type label: str
         :param fmt: conversion format for each number as used by ``format()``
@@ -597,36 +637,50 @@ class BasePoseMatrix(BasePoseList):
         Print pose in a compact single line format. If ``X`` has multiple
         values, print one per line.
 
+        Orientation can be displayed in various formats:
+
+        =============   =================================================
+        ``orient``      description
+        =============   =================================================
+        ``'rpy/zyx'``   roll-pitch-yaw angles in ZYX axis order [default]
+        ``'rpy/yxz'``   roll-pitch-yaw angles in YXZ axis order
+        ``'rpy/zyx'``   roll-pitch-yaw angles in ZYX axis order
+        ``'eul'``       Euler angles in ZYZ axis order
+        ``'angvec'``    angle and axis
+        =============   =================================================
+
+
         Example:
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE2, SE3
             >>> x = SE3.Rx(0.3)
             >>> x.printline()
-            >>> x = SE3.Rx([0.2, 0.3], 'rpy/xyz')
+            >>> x = SE3.Rx([0.2, 0.3])
             >>> x.printline()
+            >>> x.printline('angvec')
+            >>> x.printline(orient='angvec', fmt="{:.6f}")
             >>> x = SE2(1, 2, 0.3)
             >>> x.printline()
-            >>> SE3.Rand(N=3).printline(fmt='{:8.3g}')
-        
-        .. note:: 
+
+        .. note::
             - Default formatting is for compact display of data
             - For tabular data set ``fmt`` to a fixed width format such as
               ``fmt='{:.3g}'``
 
-        :seealso: :func:`trprint`, :func:`trprint2`
+        :seealso: :meth:`strline` :func:`trprint`, :func:`trprint2`
         """
         if self.N == 2:
             for x in self.data:
-                base.trprint2(x, **kwargs)
+                base.trprint2(x, *args, **kwargs)
         else:
             for x in self.data:
-                base.trprint(x, **kwargs)
-
+                base.trprint(x, *args, **kwargs)
 
     def strline(self, *args, **kwargs):
         """
-        Print pose in compact single line format (superclass method)
+        Convert pose to compact single line string (superclass method)
 
         :param label: text label to put at start of line
         :type label: str
@@ -639,30 +693,46 @@ class BasePoseMatrix(BasePoseList):
         :type orient: str
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
+        :return: pose in string format
+        :rtype: str
 
-        Print pose in a compact single line format. If ``X`` has multiple
-        values, print one per line.
+        Convert pose in a compact single line format. If ``X`` has multiple
+        values, the string has one pose per line.
+
+        Orientation can be displayed in various formats:
+
+        =============   =================================================
+        ``orient``      description
+        =============   =================================================
+        ``'rpy/zyx'``   roll-pitch-yaw angles in ZYX axis order [default]
+        ``'rpy/yxz'``   roll-pitch-yaw angles in YXZ axis order
+        ``'rpy/zyx'``   roll-pitch-yaw angles in ZYX axis order
+        ``'eul'``       Euler angles in ZYZ axis order
+        ``'angvec'``    angle and axis
+        =============   =================================================
 
         Example:
 
         .. runblock:: pycon
 
+            >>> from spatialmath import SE2, SE3
             >>> x = SE3.Rx(0.3)
-            >>> x.printline()
-            >>> x = SE3.Rx([0.2, 0.3], 'rpy/xyz')
-            >>> x.printline()
+            >>> x.strline()
+            >>> x = SE3.Rx([0.2, 0.3])
+            >>> x.strline()
+            >>> x.strline('angvec')
+            >>> x.strline(orient='angvec', fmt="{:.6f}")
             >>> x = SE2(1, 2, 0.3)
-            >>> x.printline()
-            >>> SE3.Rand(N=3).printline(fmt='{:8.3g}')
-        
-        .. note:: 
+            >>> x.strline()
+
+        .. note::
             - Default formatting is for compact display of data
             - For tabular data set ``fmt`` to a fixed width format such as
               ``fmt='{:.3g}'``
 
-        :seealso: :func:`trprint`, :func:`trprint2`
+        :seealso: :meth:`printline` :func:`trprint`, :func:`trprint2`
         """
-        s = ''
+        s = ""
         if self.N == 2:
             for x in self.data:
                 s += base.trprint2(x, *args, file=False, **kwargs)
@@ -692,20 +762,25 @@ class BasePoseMatrix(BasePoseList):
         # TODO: really should iterate over all the elements, can have a symb
         #       element and ~eps values
         def trim(x):
-            if x.dtype == 'O':
+            if x.dtype == "O":
                 return x
             else:
                 return base.removesmall(x)
 
         name = type(self).__name__
         if len(self) == 0:
-            return name + '([])'
+            return name + "([])"
         elif len(self) == 1:
             # need to indent subsequent lines of the native repr string by 4 spaces
-            return name + '(' + trim(self.A).__repr__().replace('\n', '\n    ') + ')'
+            return name + "(" + trim(self.A).__repr__().replace("\n", "\n    ") + ")"
         else:
             # format this as a list of ndarrays
-            return name + '([\n' + ',\n'.join([trim(v).__repr__() for v in self.data]) + ' ])'
+            return (
+                name
+                + "([\n"
+                + ",\n".join([trim(v).__repr__() for v in self.data])
+                + " ])"
+            )
 
     def _repr_pretty_(self, p, cycle):
         """
@@ -723,13 +798,12 @@ class BasePoseMatrix(BasePoseList):
 
         """
         # see https://ipython.org/ipython-doc/stable/api/generated/IPython.lib.pretty.html
-        
+
         if len(self) == 1:
             p.text(str(self))
         else:
             for i, x in enumerate(self):
                 p.text(f"{i}:\n{str(x)}")
-                
 
     def __str__(self):
         """
@@ -744,10 +818,10 @@ class BasePoseMatrix(BasePoseList):
 
             >>> x = SE3.Rx(0.3)
             >>> print(x)
-               1           0           0           0            
-               0           0.955336   -0.29552     0            
-               0           0.29552     0.955336    0            
-               0           0           0           1 
+               1           0           0           0
+               0           0.955336   -0.29552     0
+               0           0.29552     0.955336    0
+               0           0           0           1
 
         Notes:
 
@@ -765,7 +839,7 @@ class BasePoseMatrix(BasePoseList):
 
     def _string_matrix(self):
         if self._ansiformatter is None:
-            self._ansiformatter = ANSIMatrix(style='thick')
+            self._ansiformatter = ANSIMatrix(style="thick")
 
         return "\n".join([self._ansiformatter.str(A) for A in self.data])
 
@@ -791,48 +865,51 @@ class BasePoseMatrix(BasePoseList):
 
             >>> x = SE3.Rx(0.3)
             >>> print(str(x))
-               1           0           0           0            
-               0           0.955336   -0.29552     0            
-               0           0.29552     0.955336    0            
-               0           0           0           1 
+               1           0           0           0
+               0           0.955336   -0.29552     0
+               0           0.29552     0.955336    0
+               0           0           0           1
 
         """
-        #print('in __str__', _color)
-        
+        # print('in __str__', _color)
+
         if self._color:
 
             def color(c, f):
                 if c is None:
-                    return ''
+                    return ""
                 else:
                     return f(c)
+
             bgcol = color(self._bgcolor, bg)
             trcol = color(self._transcolor, fg) + bgcol
             rotcol = color(self._rotcolor, fg) + bgcol
             constcol = color(self._constcolor, fg) + bgcol
-            indexcol = color(self._indexcolor[0], fg) \
-                       + color(self._indexcolor[1], bg)
+            indexcol = color(self._indexcolor[0], fg) + color(self._indexcolor[1], bg)
             reset = attr(0)
         else:
-            bgcol = ''
-            trcol = ''
-            rotcol = ''
-            constcol = ''
-            reset = ''
+            bgcol = ""
+            trcol = ""
+            rotcol = ""
+            constcol = ""
+            reset = ""
 
         def mformat(self, X):
             # X is an ndarray value to be display
             # self provides set type for formatting
-            out = ''
+            out = ""
             n = self.N  # dimension of rotation submatrix
             for rownum, row in enumerate(X):
-                rowstr = ' '
+                rowstr = " "
                 # format the columns
                 for colnum, element in enumerate(row):
-                    if sym.issymbol(element):
-                        s = '{:<12s}'.format(str(element))
+                    if base.sym.issymbol(element):
+                        s = "{:<12s}".format(str(element))
                     else:
-                        if self._suppress_small and abs(element) < self._suppress_tol * _eps:
+                        if (
+                            self._suppress_small
+                            and abs(element) < self._suppress_tol * _eps
+                        ):
                             element = 0
                         s = self._format.format(element)
 
@@ -846,14 +923,14 @@ class BasePoseMatrix(BasePoseList):
                     else:
                         # bottom row
                         s = constcol + bgcol + s + reset
-                    rowstr += ' ' + s
-                out += rowstr + bgcol + '  ' + reset + '\n'
+                    rowstr += " " + s
+                out += rowstr + bgcol + "  " + reset + "\n"
             return out
 
-        output_str = ''
+        output_str = ""
 
         if len(self.data) == 0:
-            output_str = '[]'
+            output_str = "[]"
         elif len(self.data) == 1:
             # single matrix case
             output_str = mformat(self, self.A)
@@ -861,8 +938,13 @@ class BasePoseMatrix(BasePoseList):
             # sequence case
             for count, X in enumerate(self.data):
                 # add separator lines and the index
-                output_str += indexcol + '[{:d}] ='.format(count) + reset \
-                    + '\n' + mformat(self, X)
+                output_str += (
+                    indexcol
+                    + "[{:d}] =".format(count)
+                    + reset
+                    + "\n"
+                    + mformat(self, X)
+                )
 
         return output_str
 
@@ -898,10 +980,10 @@ class BasePoseMatrix(BasePoseList):
         :param `**kwargs`: plotting options
 
         - ``X.animate()`` displays the pose ``X`` as a coordinate frame moving
-          from the origin in either 2D or 3D.  There are many options, see the 
+          from the origin in either 2D or 3D.  There are many options, see the
           links below.
         - ``X.animate(*args, start=X1)`` displays the pose ``X`` as a coordinate
-          frame moving from pose ``X1``, in either 2D or 3D.  There are 
+          frame moving from pose ``X1``, in either 2D or 3D.  There are
           many options, see the links below.
 
         Example::
@@ -914,7 +996,7 @@ class BasePoseMatrix(BasePoseList):
         """
         if start is not None:
             start = start.A
-        
+
         if len(self) > 1:
             # trajectory case
             if self.N == 2:
@@ -928,8 +1010,7 @@ class BasePoseMatrix(BasePoseList):
             else:
                 base.tranimate(self.A, start=start, *args, **kwargs)
 
-
-# ------------------------------------------------------------------------ #
+    # ------------------------------------------------------------------------ #
     def prod(self):
         r"""
         Product of elements (superclass method)
@@ -986,10 +1067,12 @@ class BasePoseMatrix(BasePoseList):
 
         """
 
-        assert type(n) is int, 'exponent must be an int'
-        return self.__class__([np.linalg.matrix_power(x, n) for x in self.data], check=False)
-    #----------------------- arithmetic
+        assert type(n) is int, "exponent must be an int"
+        return self.__class__(
+            [np.linalg.matrix_power(x, n) for x in self.data], check=False
+        )
 
+    # ----------------------- arithmetic
 
     def __mul__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1064,38 +1147,49 @@ class BasePoseMatrix(BasePoseList):
         1          (N,M)        (N,M)  column transformation
         =========  ===========  =====  ==========================
 
-        .. note:: 
+        .. note::
             - The vector is an array-like, a 1D NumPy array or a list/tuple
             - For the ``SE2`` and ``SE3`` case the vectors are converted to homogeneous
               form, transformed, then converted back to Euclidean form.
 
-        Example:: 
+        Example::
 
             >>> SE3.Rx(pi/2) * [0, 1, 0]
             array([0.000000e+00, 6.123234e-17, 1.000000e+00])
             >>> SE3.Rx(pi/2) * np.r_[0, 0, 1]
             array([ 0.000000e+00, -1.000000e+00,  6.123234e-17])
         """
-        if isinstance(left, right.__class__):
-            #print('*: pose x pose')
+        if type(left) == type(right):
+            # print('*: pose x pose')
             return left.__class__(left._op2(right, lambda x, y: x @ y), check=False)
 
         elif isinstance(right, (list, tuple, np.ndarray)):
-            #print('*: pose x array')
-            if len(left) == 1 and base.isvector(right, left.N):
-                # pose x vector
-                #print('*: pose x vector')
-                v = base.getvector(right, out='col')
-                if left.isSE:
-                    # SE(n) x vector
-                    return base.h2e(left.A @ base.e2h(v))
+            # print('*: pose x array')
+            if len(left) == 1:
+                if base.isvector(right, left.N):
+                    # pose x vector
+                    # print('*: pose x vector')
+                    v = base.getvector(right, out="col")
+                    if left.isSE:
+                        # SE(n) x vector
+                        return base.h2e(left.A @ base.e2h(v))
+                    else:
+                        # SO(n) x vector
+                        return left.A @ v
+                elif left.isSE and right.shape == left.shape:
+                    # SE x conforming matrix
+                    return left.A @ right
                 else:
-                    # SO(n) x vector
-                    return left.A @ v
+                    if left.isSE:
+                        # SE(n) x [set of vectors]
+                        return base.h2e(left.A @ base.e2h(right))
+                    else:
+                        # SO(n) x [set of vectors]
+                        return left.A @ right
 
             elif len(left) > 1 and base.isvector(right, left.N):
                 # pose array x vector
-                #print('*: pose array x vector')
+                # print('*: pose array x vector')
                 v = base.getvector(right)
                 if left.isSE:
                     # SE(n) x vector
@@ -1105,20 +1199,42 @@ class BasePoseMatrix(BasePoseList):
                     # SO(n) x vector
                     return np.array([(x @ v).flatten() for x in left.A]).T
 
-            elif len(left) == 1 and isinstance(right, np.ndarray) and left.isSO and right.shape[0] == left.N:
+            elif (
+                len(left) == 1
+                and isinstance(right, np.ndarray)
+                and left.isSO
+                and right.shape[0] == left.N
+            ):
                 # SO(n) x matrix
                 return left.A @ right
-            elif len(left) == 1 and isinstance(right, np.ndarray) and left.isSE and right.shape[0] == left.N:
+            elif (
+                len(left) == 1
+                and isinstance(right, np.ndarray)
+                and left.isSE
+                and right.shape[0] == left.N
+            ):
                 # SE(n) x matrix
                 return base.h2e(left.A @ base.e2h(right))
-            elif isinstance(right, np.ndarray) and left.isSO and right.shape[0] == left.N and len(left) == right.shape[1]:
+            elif (
+                isinstance(right, np.ndarray)
+                and left.isSO
+                and right.shape[0] == left.N
+                and len(left) == right.shape[1]
+            ):
                 # SO(n) x matrix
                 return np.c_[[x.A @ y for x, y in zip(right, left.T)]].T
-            elif isinstance(right, np.ndarray) and left.isSE and right.shape[0] == left.N and len(left) == right.shape[1]:
+            elif (
+                isinstance(right, np.ndarray)
+                and left.isSE
+                and right.shape[0] == left.N
+                and len(left) == right.shape[1]
+            ):
                 # SE(n) x matrix
-                return np.c_[[base.h2e(x.A @ base.e2h(y)) for x, y in zip(right, left.T)]].T
+                return np.c_[
+                    [base.h2e(x.A @ base.e2h(y)) for x, y in zip(right, left.T)]
+                ].T
             else:
-                raise ValueError('bad operands')
+                raise ValueError("bad operands")
         elif base.isscalar(right):
             return left._op2(right, lambda x, y: x * y)
         else:
@@ -1137,16 +1253,18 @@ class BasePoseMatrix(BasePoseList):
           and places the result in ``X``
 
         .. note:: This operator is functionally equivalent to ``*`` but is more
-            costly.  It is useful for cases where a pose is incrementally 
+            costly.  It is useful for cases where a pose is incrementally
             update over many cycles.
 
         :seealso: :func:`__mul__`, :func:`~spatialmath.base.trnorm`
         """
         if isinstance(left, right.__class__):
-            #print('*: pose x pose')
-            return left.__class__(left._op2(right, lambda x, y: base.trnorm(x @ y)), check=False)
+            # print('*: pose x pose')
+            return left.__class__(
+                left._op2(right, lambda x, y: base.trnorm(x @ y)), check=False
+            )
         else:
-            raise TypeError('@ only applies to pose composition')
+            raise TypeError("@ only applies to pose composition")
 
     def __rmul__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1168,10 +1286,11 @@ class BasePoseMatrix(BasePoseList):
 
         :seealso: :func:`__mul__`
         """
-        if base.isscalar(left):
-            return right.__mul__(left)
-        else:
-            return NotImplemented
+        # if base.isscalar(left):
+        #     return right.__mul__(left)
+        # else:
+        #     return NotImplemented
+        return right.__mul__(left)
 
     def __imul__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1215,7 +1334,7 @@ class BasePoseMatrix(BasePoseList):
 
             #. Pose is ``SO2``, ``SE2``, ``SO3`` or ``SE3`` instance
             #. N is 2 for ``SO2``, ``SE2``; 3 for ``SO3`` or ``SE3``
-            #. Scalar multiplication is not a group operation so the result will 
+            #. Scalar multiplication is not a group operation so the result will
                be a matrix
             #. Any other input combinations result in a ValueError.
 
@@ -1234,11 +1353,13 @@ class BasePoseMatrix(BasePoseList):
 
         """
         if isinstance(left, right.__class__):
-            return left.__class__(left._op2(right.inv(), lambda x, y: x @ y), check=False)
+            return left.__class__(
+                left._op2(right.inv(), lambda x, y: x @ y), check=False
+            )
         elif base.isscalar(right):
             return left._op2(right, lambda x, y: x / y)
         else:
-            raise ValueError('bad operands')
+            raise ValueError("bad operands")
 
     def __itruediv__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1306,7 +1427,7 @@ class BasePoseMatrix(BasePoseList):
         # results is not in the group, return an array, not a class
         return left._op2(right, lambda x, y: x + y)
 
-    def __radd__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __radd__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``+`` operator (superclass method)
 
@@ -1320,8 +1441,7 @@ class BasePoseMatrix(BasePoseList):
 
         :seealso: :meth:`__add__`
         """
-        return left.__add__(right)
-
+        return right.__add__(left)
 
     def __iadd__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1389,7 +1509,7 @@ class BasePoseMatrix(BasePoseList):
         # TODO allow class +/- a conformant array
         return left._op2(right, lambda x, y: x - y)
 
-    def __rsub__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+    def __rsub__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``-`` operator (superclass method)
 
@@ -1403,7 +1523,7 @@ class BasePoseMatrix(BasePoseList):
 
         :seealso: :meth:`__sub__`
         """
-        return -left.__sub__(right)
+        return -right.__sub__(left)
 
     def __isub__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1447,8 +1567,8 @@ class BasePoseMatrix(BasePoseList):
         =========   ==========   ====  ================================
 
         """
-        assert type(left) == type(right), 'operands to == are of different types'
-        return left._op2(right, lambda x, y: np.allclose(x, y))
+        return (left._op2(right, lambda x, y: np.allclose(x, y))
+                if type(left) == type(right) else False)
 
     def __ne__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1475,7 +1595,8 @@ class BasePoseMatrix(BasePoseList):
         =========   ==========   ====  ================================
 
         """
-        return [not x for x in left == right]
+        eq = left == right
+        return (not eq if isinstance(eq, bool) else [not x for x in eq])
 
     def _op2(left, right, op):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
@@ -1491,8 +1612,8 @@ class BasePoseMatrix(BasePoseList):
         :return: list of matrices
         :rtype: list
 
-        Peform a binary operation on a pair of operands.  If either operand
-        contains a sequence the results is a sequence accordinging to this
+        Perform a binary operation on a pair of operands.  If either operand
+        contains a sequence the results is a sequence according to this
         truth table.
 
         =========   ==========   ====  ================================
@@ -1509,29 +1630,38 @@ class BasePoseMatrix(BasePoseList):
             # class by class
             if len(left) == 1:
                 if len(right) == 1:
-                    #print('== 1x1')
+                    # print('== 1x1')
                     return op(left.A, right.A)
                 else:
-                    #print('== 1xN')
+                    # print('== 1xN')
                     return [op(left.A, x) for x in right.A]
             else:
                 if len(right) == 1:
-                    #print('== Nx1')
+                    # print('== Nx1')
                     return [op(x, right.A) for x in left.A]
                 elif len(left) == len(right):
-                    #print('== NxN')
+                    # print('== NxN')
                     return [op(x, y) for (x, y) in zip(left.A, right.A)]
                 else:
-                    raise ValueError('length of lists to == must be same length')
-        elif base.isscalar(right) or (isinstance(right, np.ndarray) and right.shape == left.shape):
+                    raise ValueError("length of lists to == must be same length")
+        elif base.isscalar(right) or (
+            isinstance(right, np.ndarray) and right.shape == left.shape
+        ):
             # class by matrix
             if len(left) == 1:
                 return op(left.A, right)
             else:
                 return [op(x, right) for x in left.A]
 
+
 if __name__ == "__main__":
-    from spatialmath import SE3
+    from spatialmath import SE3, SE2
+
     x = SE3.Rand(N=6)
 
-    x.printline('rpy/xyz', fmt='{:8.3g}')
\ No newline at end of file
+    x.printline(orient="rpy/xyz", fmt="{:8.3g}")
+
+    d = np.diag([0.25, 0.25, 1])
+    a = SE2()
+    print(a)
+    print(d * a)
