@@ -6,9 +6,6 @@ Created on Sun Jul  5 09:42:30 2020
 @author: corkep
 """
 from functools import reduce
-from math import gamma
-from random import betavariate
-from ssl import ALERT_DESCRIPTION_HANDSHAKE_FAILURE
 from spatialmath import base, SE2
 import matplotlib.pyplot as plt
 from matplotlib.path import Path
